@@ -1,7 +1,8 @@
 from .value_checks import (is_a_date, is_a_int, is_a_bool, is_a_float, 
-    is_a_coord, is_a_coord_pair)
+    is_a_coord, is_a_coord_pair, is_a_city)
 from .list_checks import column_probability_for_type
 import collections
+from address import AddressParser
 
 """Takes a list of values and returns a type signature
 
@@ -79,6 +80,46 @@ def rows_types_probabilities(rows, headers=[], num_rows=100):
     return types
 
 
+
+"""Determine if a column is an address that can be separated into city, state, 
+and zipcode
+
+:param values: a list of values
+:param num_rows: max number of rows to test
+:returns a dict with city, state and zip probabilities
+"""
+def address_parts_probabilities(values, num_rows=100):
+    len_values = len(values)
+    ap = AddressParser()
+    has = { 'city': 0, 'state': 0, 'zip': 0 }
+    probs = { 'city': 0, 'state': 0, 'zip': 0 }
+    max_rows = num_rows if num_rows < len_values - 1 else len_values - 1 
+        
+    if not column_probability_for_type(values[:max_rows], 'address') > .5:
+        return probs
+
+    for v in values[:max_rows]:
+        if ',' not in v:
+            tokens = v.split(' ')
+            for i,token in enumerate(tokens):
+                if len(token) > 1 and is_a_city(token):
+                    tokens[i] = token + ','
+                    break
+
+            v = ' '.join(tokens)
+
+        addr = ap.parse_address(v)
+        for k in has.keys():
+            if getattr(addr, k, None):
+                has[k] += 1
+
+    for k in probs.keys():
+        probs[k] = float(has[k]) / max_rows
+
+    return probs
+
+
+
 def categories_from_list(values):
     non_empty = [r for r in values if r != '']
     threshold = int(.05 * len(non_empty))
