@@ -35,6 +35,24 @@ def is_a_date(value, key=None):
         else:
             return False
 
+    if is_a_float(value, key):
+        keyl = str(key).lower()
+        if 'date' in keyl or 'time' in keyl:
+            return True
+
+        if float(value) < 0:
+            return False
+
+        """
+        This is iffy. Obviously it's totally possible to have infinitely 
+        precise measurements, but we're going to guess that if there are 
+        more numbers to the right of the decimal point than the left, we 
+        are probably dealing with a coordinate (or something)
+        """
+        pieces = str(value).split('.')
+        if len(pieces[1]) > len(pieces[0]):
+            return False
+
     return True
 
 
@@ -81,17 +99,14 @@ def is_a_coord(value, key=None, pos=None):
     if key and key in ['latitude', 'longitude'] and is_a_int(value):
         return True
 
-    if not is_a_int(value, key=key) or not is_a_float(value, key=key):
-        return False
-
-    if not len(str(value)) < 15:
+    if not is_a_int(value, key=key) and not is_a_float(value, key=key):
         return False
 
     if not abs(float(value)) <= 180:
         return False
 
     # so we know we have a value that is between -180 and 180
-    key_names = ['lat', 'lon', 'lng', 'coords', 'coordinates']
+    key_names = ['lat', 'lon', 'lng', 'long', 'coords', 'coordinates']
     if key and any([k in key for k in key_names]):
         return True
 
@@ -170,6 +185,30 @@ def is_a_country(value, key=None, pos=None):
     return is_a_place(value, 'country', key=key)
 
 
+def is_a_zip(value, key=None, pos=None):
+    if key:
+        key = str(key).lower().strip()
+
+    if key and key in ['zip', 'zipcode', 'postal code']:
+        return True
+
+    if '-' in str(value):
+        if len(value) == 10:
+            return True
+
+        primary = str(value).split('-')[0]
+    else:
+        primary = value
+
+    if not is_a_int(value):
+        return False
+
+    if len(str(value)) == 5 and int(value) > 499:
+        return True
+
+    return False
+
+
 def is_a_address(value, key=None, pos=None):
     if not is_a_str(value):
         return False
